.. _module_hydra_core_servicehead:

servicehead
===========

This sections contains module documentation of servicehead module.

servicehead
^^^^^^^^^^^

Method provides class ServiceHead.
Unit tests available at hydratk/core/servicehead/01_methods_ut.jedi

**Methods** :

* srv_async_cb

Method sends callback via message queue.